@@ -14,6 +14,7 @@ import java.util.Map;
 import java.util.logging.Level;
 import yahoofinance.Utils;
 import yahoofinance.YahooFinance;
+import yahoofinance.util.RedirectableRequest;
 
 /**
  *
@@ -83,9 +84,9 @@ public class HistQuotesRequest {
 
         List<HistoricalQuote> result = new ArrayList<HistoricalQuote>();
         
-        if(this.from.equals(this.to) || this.from.after(this.to)) {
+        if(this.from.after(this.to)) {
             YahooFinance.logger.log(Level.WARNING, "Unable to retrieve historical quotes. "
-                    + "From-date should be at least 1 day before to-date. From: " 
+                    + "From-date should not be after to-date. From: "
                     + this.from.getTime() + ", to: " + this.to.getTime());
             return result;
         }
@@ -111,9 +112,11 @@ public class HistQuotesRequest {
         YahooFinance.logger.log(Level.INFO, ("Sending request: " + url));
 
         URL request = new URL(url);
-        URLConnection connection = request.openConnection();
-        connection.setConnectTimeout(YahooFinance.CONNECTION_TIMEOUT);
-        connection.setReadTimeout(YahooFinance.CONNECTION_TIMEOUT);
+        RedirectableRequest redirectableRequest = new RedirectableRequest(request, 5);
+        redirectableRequest.setConnectTimeout(YahooFinance.CONNECTION_TIMEOUT);
+        redirectableRequest.setReadTimeout(YahooFinance.CONNECTION_TIMEOUT);
+        URLConnection connection = redirectableRequest.openConnection();
+
         InputStreamReader is = new InputStreamReader(connection.getInputStream());
         BufferedReader br = new BufferedReader(is);
         br.readLine(); // skip the first line
